@@ -48,136 +48,136 @@ GLIBTOP_SUID_NETLOAD +
 GLIBTOP_SUID_NETLIST +
 GLIBTOP_SUID_PPP;
 
-const glibtop_init_func_t _glibtop_init_hook_s [] = {
+const _glibtop_init_func_t _glibtop_init_hook_s [] = {
 #if !GLIBTOP_SUID_CPU
-	glibtop_init_cpu_s,
+	_glibtop_init_cpu_s,
 #endif
 #if !GLIBTOP_SUID_MEM
-	glibtop_init_mem_s,
+	_glibtop_init_mem_s,
 #endif
 #if !GLIBTOP_SUID_SWAP
-	glibtop_init_swap_s,
+	_glibtop_init_swap_s,
 #endif
 #if !GLIBTOP_SUID_UPTIME
-	glibtop_init_uptime_s,
+	_glibtop_init_uptime_s,
 #endif
 #if !GLIBTOP_SUID_LOADAVG
-	glibtop_init_loadavg_s,
+	_glibtop_init_loadavg_s,
 #endif
 #if !GLIBTOP_SUID_SHM_LIMITS
-	glibtop_init_shm_limits_s,
+	_glibtop_init_shm_limits_s,
 #endif
 #if !GLIBTOP_SUID_MSG_LIMITS
-	glibtop_init_msg_limits_s,
+	_glibtop_init_msg_limits_s,
 #endif
 #if !GLIBTOP_SUID_SEM_LIMITS
-	glibtop_init_sem_limits_s,
+	_glibtop_init_sem_limits_s,
 #endif
 #if !GLIBTOP_SUID_PROCLIST
-	glibtop_init_proclist_s,
+	_glibtop_init_proclist_s,
 #endif
 #if !GLIBTOP_SUID_PROC_STATE
-	glibtop_init_proc_state_s,
+	_glibtop_init_proc_state_s,
 #endif
 #if !GLIBTOP_SUID_PROC_UID
-	glibtop_init_proc_uid_s,
+	_glibtop_init_proc_uid_s,
 #endif
 #if !GLIBTOP_SUID_PROC_MEM
-	glibtop_init_proc_mem_s,
+	_glibtop_init_proc_mem_s,
 #endif
 #if !GLIBTOP_SUID_PROC_TIME
-	glibtop_init_proc_time_s,
+	_glibtop_init_proc_time_s,
 #endif
 #if !GLIBTOP_SUID_PROC_SIGNAL
-	glibtop_init_proc_signal_s,
+	_glibtop_init_proc_signal_s,
 #endif
 #if !GLIBTOP_SUID_PROC_KERNEL
-	glibtop_init_proc_kernel_s,
+	_glibtop_init_proc_kernel_s,
 #endif
 #if !GLIBTOP_SUID_PROC_SEGMENT
-	glibtop_init_proc_segment_s,
+	_glibtop_init_proc_segment_s,
 #endif
 #if !GLIBTOP_SUID_PROC_ARGS
-	glibtop_init_proc_args_s,
+	_glibtop_init_proc_args_s,
 #endif
 #if !GLIBTOP_SUID_PROC_MAP
-	glibtop_init_proc_map_s,
+	_glibtop_init_proc_map_s,
 #endif
 #if !GLIBTOP_SUID_NETLOAD
-	glibtop_init_netload_s,
+	_glibtop_init_netload_s,
 #endif
 #if !GLIBTOP_SUID_NETLIST
-	glibtop_init_netlist_s,
+	_glibtop_init_netlist_s,
 #endif
 #if !GLIBTOP_SUID_PPP
-	glibtop_init_ppp_s,
+	_glibtop_init_ppp_s,
 #endif
 	NULL
 };
 
-const glibtop_init_func_t _glibtop_init_hook_p [] = {
+const _glibtop_init_func_t _glibtop_init_hook_p [] = {
 #if GLIBTOP_SUID_CPU
-	glibtop_init_cpu_p,
+	_glibtop_init_cpu_p,
 #endif
 #if GLIBTOP_SUID_MEM
-	glibtop_init_mem_p,
+	_glibtop_init_mem_p,
 #endif
 #if GLIBTOP_SUID_SWAP
-	glibtop_init_swap_p,
+	_glibtop_init_swap_p,
 #endif
 #if GLIBTOP_SUID_UPTIME
-	glibtop_init_uptime_p,
+	_glibtop_init_uptime_p,
 #endif
 #if GLIBTOP_SUID_LOADAVG
-	glibtop_init_loadavg_p,
+	_glibtop_init_loadavg_p,
 #endif
 #if GLIBTOP_SUID_SHM_LIMITS
-	glibtop_init_shm_limits_p,
+	_glibtop_init_shm_limits_p,
 #endif
 #if GLIBTOP_SUID_MSG_LIMITS
-	glibtop_init_msg_limits_p,
+	_glibtop_init_msg_limits_p,
 #endif
 #if GLIBTOP_SUID_SEM_LIMITS
-	glibtop_init_sem_limits_p,
+	_glibtop_init_sem_limits_p,
 #endif
 #if GLIBTOP_SUID_PROCLIST
-	glibtop_init_proclist_p,
+	_glibtop_init_proclist_p,
 #endif
 #if GLIBTOP_SUID_PROC_STATE
-	glibtop_init_proc_state_p,
+	_glibtop_init_proc_state_p,
 #endif
 #if GLIBTOP_SUID_PROC_UID
-	glibtop_init_proc_uid_p,
+	_glibtop_init_proc_uid_p,
 #endif
 #if GLIBTOP_SUID_PROC_MEM
-	glibtop_init_proc_mem_p,
+	_glibtop_init_proc_mem_p,
 #endif
 #if GLIBTOP_SUID_PROC_TIME
-	glibtop_init_proc_time_p,
+	_glibtop_init_proc_time_p,
 #endif
 #if GLIBTOP_SUID_PROC_SIGNAL
-	glibtop_init_proc_signal_p,
+	_glibtop_init_proc_signal_p,
 #endif
 #if GLIBTOP_SUID_PROC_KERNEL
-	glibtop_init_proc_kernel_p,
+	_glibtop_init_proc_kernel_p,
 #endif
 #if GLIBTOP_SUID_PROC_SEGMENT
-	glibtop_init_proc_segment_p,
+	_glibtop_init_proc_segment_p,
 #endif
 #if GLIBTOP_SUID_PROC_ARGS
-	glibtop_init_proc_args_p,
+	_glibtop_init_proc_args_p,
 #endif
 #if GLIBTOP_SUID_PROC_MAP
-	glibtop_init_proc_map_p,
+	_glibtop_init_proc_map_p,
 #endif
 #if GLIBTOP_SUID_NETLOAD
-	glibtop_init_netload_p,
+	_glibtop_init_netload_p,
 #endif
 #if GLIBTOP_SUID_NETLIST
-	glibtop_init_netlist_p,
+	_glibtop_init_netlist_p,
 #endif
 #if GLIBTOP_SUID_PPP
-	glibtop_init_ppp_p,
+	_glibtop_init_ppp_p,
 #endif
 	NULL
 };
