@@ -1,5 +1,3 @@
-/* $Id: open.c,v 1.28 2005/12/14 10:53:53 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -50,7 +48,7 @@ static void set_linux_version(glibtop *server)
 			       uts.release, x, y, z, LINUX_VERSION_CODE(x,y,z));
 
 	if (LINUX_VERSION_CODE(x, y, z) >= LINUX_VERSION_CODE(2, 6, 0)
-	    && !g_file_test("/sys", G_FILE_TEST_IS_DIR))
+	    && !has_sysfs())
 		glibtop_warn_r(server,
 			       "You're running a 2.6 kernel without /sys."
 			       "You should mount it.");
@@ -91,9 +89,11 @@ glibtop_open_s (glibtop *server, const char *program_name,
 
 	server->ncpu = MIN(GLIBTOP_NCPU - 1, server->real_ncpu);
 
-	glibtop_warn_r(server,
-		       "This machine has %d CPUs, "
-		       "%d are being monitored.",
-		       server->real_ncpu + 1,
-		       server->ncpu + 1);
+	if (server->real_ncpu != server->ncpu) {
+		glibtop_warn_r(server,
+			       "This machine has %d CPUs, "
+			       "%d are being monitored.",
+			       server->real_ncpu + 1,
+			       server->ncpu + 1);
+	}
 }
