@@ -1,5 +1,3 @@
-/* $Id: ppp.c 2422 2005-12-12 09:38:15Z jamesh $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -48,7 +46,7 @@ static const unsigned long _glibtop_sysdeps_ppp =
 /* Init function. */
 
 void
-glibtop_init_ppp_s (glibtop *server)
+_glibtop_init_ppp_s (glibtop *server)
 {
 	server->sysdeps.ppp = _glibtop_sysdeps_ppp;
 }
