@@ -35,7 +35,7 @@ static const unsigned long _glibtop_sysdeps_proc_kernel =
 /* Init function. */
 
 void
-glibtop_init_proc_kernel_s (glibtop *server)
+_glibtop_init_proc_kernel_s (glibtop *server)
 {
 	server->sysdeps.proc_kernel = _glibtop_sysdeps_proc_kernel;
 }
